<?php
namespace UCFW\Front;

class Initialize
{
    public static $instance;
    private $helper;

    public static function getInstance()
    {
        if ( !self::$instance instanceof self )
            self::$instance = new self();
        
        return self::$instance;
    }

    private function __construct()
    {
        $this->helper = \UCFW\Helper::getInstance();
      
        add_action( 'wp_enqueue_scripts',                     array( $this, 'enqueue' ) );
        add_action( 'wp_head',                                array( $this, 'inlineStyles' ) );
        add_filter( 'woocommerce_coupon_get_discount_amount', array( $this, 'applyMaxDiscountAmount' ), 20, 5 );
    }
   
    public function enqueue()
    {
        $this->styles();
        $this->scripts();
    }

    private function styles()
    {
        wp_enqueue_style( 'ucfw' );
        wp_enqueue_style( 'ucfw-front' );
        wp_enqueue_style( 'ucfw-front-templates' );
        wp_enqueue_style( 'ucfw-animate' );
    }

    private function scripts()
    {
        wp_enqueue_script( 'ucfw-serializejson' );
        wp_enqueue_script( 'ucfw-front-templates' );
    }

    /**
     * Inline styles
     *
     * @return array
     */
    public function inlineStyles()
    { 
        $borderWidth     = get_option( '_ucfw_deals_apply_item_border_width', '5px' );
        $borderColor     = get_option( '_ucfw_deals_apply_item_border_color', '#000000' );
        $backgroundColor = get_option( '_ucfw_deals_apply_item_background_color', '#ffffff' );

        if ( empty($borderWidth) )
            $borderWidth = '5px';
        
        if ( empty($borderColor) )
            $borderColor = '#000000';
        
        if ( empty($backgroundColor) )
            $backgroundColor = '#ffffff';
    ?>
    <style>
        .ucfw-deals-cart-apply-item {
            border-left: <?php echo wp_kses( $borderWidth, array() ); ?> solid <?php echo wp_kses( $borderColor, array() ); ?>;
            background-color: <?php echo wp_kses( $backgroundColor, array() ); ?>;
        }
    </style>
    <?php
    }

    /**
     * Apply maximum discount in cart
     *
     * @return integer
     */
    public function applyMaxDiscountAmount( $discount, $discountingAmount, $cartItem, $single, $coupon )
    {
        $couponType = $coupon->get_discount_type();

        if ( 'percent' !== $couponType )
            return $discount;

        $maxDiscount = get_post_meta( $coupon->get_id(), 'ucfw_max_discount', true );

        if ( is_numeric($maxDiscount) && !is_null($cartItem) && WC()->cart->subtotal_ex_tax )
        {
            $cartItemQuantity = is_null( $cartItem ) ? 1 : $cartItem['quantity'];            
            
            if ( wc_prices_include_tax() )
                $discountPercent = ( wc_get_price_including_tax( $cartItem['data'] ) * $cartItemQuantity ) / WC()->cart->subtotal;
            else
                $discountPercent = ( wc_get_price_excluding_tax( $cartItem['data'] ) * $cartItemQuantity ) / WC()->cart->subtotal_ex_tax;            
                
            $discountPercent = round ( $discountPercent, 4 );
            $new             = round( ( $maxDiscount * $discountPercent ), wc_get_price_decimals() );
            $discount        = min( $new, $discount );
        }

        $discIncrease = WC()->session->get( 'ucfw_maxdisc_incr', 0 ) + $discount;
        $sessQuantity = WC()->session->get( 'ucfw_maxdisc_items', 0 ) + 1;

        WC()->session->set( 'ucfw_maxdisc_items', $sessQuantity );
        WC()->session->set( 'ucfw_maxdisc_incr',  $discIncrease );

        $cartItems        = WC()->cart->get_cart_contents();
        $cartItemQuantity = count($cartItems);

        if ( $sessQuantity == $cartItemQuantity )
        {
            if ( $discIncrease > $maxDiscount )
                $discount = $discount - ($discIncrease - $maxDiscount);
            else
                $discount = $discount + ($maxDiscount - $discIncrease);

            WC()->session->set( 'ucfw_maxdisc_items', 0 );
            WC()->session->set( 'ucfw_maxdisc_incr',  0 );
        }

        return $discount;
    }
}
